@@ -17,12 +17,13 @@ class Utils(Object):
 
 		#
 
-	# create tempalte data.
+	# create template data.
 	def template(self, old={}, new={}, safe=False):
 		if isinstance(old, (Dictionary)):
 			old = dict(old.dictionary)
 		else:
 			old = dict(old)
+		if old == None or old == "None": old = {}
 		if new == None or new == "None": return old
 		if isinstance(new, (Dictionary)):
 			new = new.dictionary
@@ -32,13 +33,13 @@ class Utils(Object):
 			raise dev0s.exceptions.InvalidUsage(f"<website.utils.template>: Parameter [new] requires to be a [dict] not [{new.__class__.__name__}] ({new}).")
 		if not isinstance(old, (dict, Dictionary)):
 			raise dev0s.exceptions.InvalidUsage(f"<website.utils.template>: Parameter [old] requires to be a [dict, Dictionary] not [{new.__class__.__name__}] ({new}).")
-		new = Dictionary(old) + Dictionary(new)
+		if new != old:
+			new = Dictionary(old) + Dictionary(new)
 		if isinstance(new, (Dictionary)): new = new.dictionary
 		if safe:
 			return self.serialize_template(new)
 		else:
 			return new
-		
 
 	# serialize dictionary to template safe dict.
 	def serialize_template(self, value={}):
